Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/touchscreen_simpletest.py
    :caption: examples/touchscreen_simpletest.py
    :linenos:


Orientation Example
--------------------

Example showing how to setup the different display orientations

.. literalinclude:: ../examples/touchscreen_orientation.py
    :caption: examples/touchscreen_orientation.py
    :linenos:
